=======
Scrapyd
=======
|PyPI Version| |Build Status| |Coverage Status| |Python Version| |Pypi Downloads|

Scrapyd is a service for running `Scrapy`_ spiders.

It allows you to deploy your Scrapy projects and control their spiders using an
HTTP JSON API.

The documentation (including installation and usage) can be found at:
http://scrapyd.readthedocs.org/


.. |PyPI Version| image:: https://img.shields.io/pypi/v/scrapyd.svg
   :target: https://pypi.org/project/scrapyd/
.. |Build Status| image:: https://github.com/scrapy/scrapyd/workflows/Tests/badge.svg
.. |Coverage Status| image:: https://codecov.io/gh/scrapy/scrapyd/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/scrapy/scrapyd
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/scrapyd.svg
   :target: https://pypi.org/project/scrapydt/
.. |Pypi Downloads| image:: https://img.shields.io/pypi/dm/scrapyd.svg
   :target: https://pypi.python.org/pypi/scrapyd/
.. _Scrapy: https://github.com/scrapy/scrapy
